/*-----------------------------------------------------------------
  All code is provided for EDUCATIONAL purposes ONLY. There is no
  warranty and no support.

  Released under the MIT License  - see
  http://www.opensource.org/licenses/mit-license.php

  interrupt.c  by Jack Botner

  This module contains the interrupt handlers.
-----------------------------------------------------------------*/
#include <avr/io.h>
#include <avr/interrupt.h>
#include "main.h"

extern volatile uint8_t  ucEventFlags;		// event flags
extern volatile uint8_t  ucT0OFCtr;
extern volatile uint16_t uiT0Ctr;
static volatile uint8_t  ucOFctr=0;

/*-----------------------------------------------------------------
  ISR(TIMER0_OVF_vect)

  Timer 0 overflow interrupt handler. 

  Clock source is T0 pin. Counts to 65535 then generates this
  interrupt and resets to 0.
-----------------------------------------------------------------*/
ISR(TIMER0_OVF_vect)
{
  ++ucOFctr;
}

/*-----------------------------------------------------------------
  ISR(TIMER1_OVF_vect)

  Timer 1 overflow interrupt handler. Generates 1 second interrupts
  for timing purposes. 

  System clock frequency = 8 mHz
  System clock period = 0.125 us
  Prescaler = 16384
  Timer count period = 2048 us
  Counts = 244
  Interrupt period = 0.499712 sec.
  Doubled up = .999424 sec.
-----------------------------------------------------------------*/
ISR(TIMER1_OVF_vect)
{
  static volatile uint8_t iCtr=0;
  uint8_t nn;

  ++iCtr;
  if ( iCtr == 2 )
  {
    set_bit( ucEventFlags, EVENT_1SEC );
    iCtr = 0;

    // Read timer 0, save values and reset
    nn = TCNT0L;  //low byte must be read before the high byte
    uiT0Ctr = ( (unsigned int) TCNT0H << 8 ) | (unsigned int) nn;
    ucT0OFCtr = ucOFctr;
    ucOFctr = 0;
    TCNT0H = 0;
    TCNT0L = 0;
  }

  TC1H = 0;
  TCNT1 = INIT_TIMER1;		// reset the timer1 counter
}


